***************************************************************************
*			Money with and without dividends
*  			3- Analysis of Data
***************************************************************************


clear all
capture log close
cd C:\temp\DATA\DataAnalysis
log using "analysis`c(current_date)'.log", replace

set more 1
set scheme sol
set autotabgraphs on  

use data_used.dta
save temp_data.dta, replace
macro define data "temp_data.dta, clear"

use $data


*==============================================================
*	OVERVIEW of DATA
*==============================================================
distinct treat ymd ID

preserve 
* Session level
	collapse session ymd session_duration  duration subj_session, by(treatment sessionID  game groupID)
	collapse   No_Subjects=subj_session 	session ymd  duration session_duration (count) groupID No_groups=groupID, by(treatment sessionID)
	replace duration=round(duration,1) 
	dis "TREATMENETS AND SESSIONS"
	list treatment ymd sessionID session_duration duration No_groups No_Subjects, sepby(treatment) ab(16)
		
* TREATMENT level
	collapse duration session_duration (count)  No_sessions=ymd (sum) No_Subjects No_groups, by(treatment)
	replace duration=round(duration,1) 
	replace session_duration=round(session_duration,1) 
	dis "TREATMENTS"
	list treatment No_groups  No_sessions session_duration duration No_Subjects,  ab(16)  sepby(treat) 
restore
	
	
*** SEX & PAYMENTS & DSTB. of LENGTH OF SUPERGAME ***
	table treat, c(m sex) row
	
	gen tot_pay=paid+quiz+7
	sum  tot_pay
	
	groups(period)
	



*==============================================================
*	 SCATTERPLOT: Efficiency &   use of Monetary Strategy
*==============================================================
preserve
	drop if period>16

* Choices consistent with Monetary trade strategy
	gen moneytrade=0
	replace moneytrade=1 if (choice==2 | choice==3 | choice==6 | choice==7)

	collapse moneytrade trade profit_partial size_d, by(treatment sessionID game group)
	gen efficiency=(profit_partial-4.5)/(7.5-4.5)

	pwcorr moneytrade efficiency, o sig p(.1) star(.05)

	gen plain=0
	replace plain =1 if size_d==0
	label variable plain "Economy with plain token(s) only"
	
	count if plain==1
		local obs1=r(N)
	count if plain==0
		local obs0=r(N)

	table plain if efficiency>=0.50, c(N eff)
	
	
*** 	FIGURE: Scatterplot***
	gen DEP=moneytrade
	
	tw      (scatter efficiency DEP  if inlist(treatment, 2,5) | (treatment==7 & game<3), connect(none ) lcolor(black) lw(medthick ) msymbol(o)  lpattern(dash)  mfc(gs12) mlc(black) mlw(medthick)  msiz(large) )      (scatter efficiency DEP if inlist(treatment,1,3,4,6) | (treatment==7 & game>2), connect(none) lcolor(black) lw(medthick ) msymbol(x)  lpattern(solid)  mfc(none) mlc(red) mlw(medthick )  msiz(large ) )    (function y=x, range (0 1) lw(medthick ) lpattern(dash) lcolor(gs8) ) ,   xlabels(0(0.25)1, labs(medsmall) )    yscale(range(0(0.25)1))  ytitle(Realized Efficiency)    ylabels(0(0.25)1, nogrid)    xtitle(Monetary Trade, size(medsmall) )             legend(order(1 "Plain tokens, only"   2 "Other tokens or mix")  ring(0) pos(5) rows(4)  size(small) symxsize(*0.35)  region(lstyle(solid))  )       graphregion(style(none) color(gs16))  plotregion(margin(zero))   scale(1.3) 

	graph export scatter.eps, as(eps) preview(off) replace 	
	
	
*** 	FIGURE :  Distribution  ***
	cumul efficiency if plain==0, gen(eff_0)
	cumul efficiency if plain==1, gen(eff_1)
	
	tw    (scatter    eff_0 efficiency , sort connect(none ) lcolor(black) lw(medthick ) msymbol(o)  lpattern(solid)  mfc(gs16) mlc(black) mlw(medium)  msiz(small) )      (scatter    eff_1 efficiency , sort connect(none) lcolor(black) lw(medthick ) msymbol(d)  lpattern(dash)  mfc(red) mlc(black) mlw(medium)  msiz(small) ) , ylab(, grid)   ytitle("CdF")     xlab(, grid) 	xlabels(0(0.25)1, labs(medsmall) )    ylabels(0(0.25)1, labs(medsmall) )     yscale(range(0(0.25)1))  ytitle(C. d. F.)     xtitle(Realized Efficiency in the Economy)    legend(order(1 "Other tokens or mix (N= `obs0') " 2 "Plain tokens, only (N=`obs1') "   )  ring(0) pos(5) rows(2)  size(small) symxsize(*0.35)  region(lstyle(solid))  )       graphregion(style(none) color(gs16))  plotregion(margin(zero))   scale(1.3) 
	
	graph export efficiencyCDF.eps, as(eps) preview(off) replace 	

restore





*==============================================================
***	GLM REGRESSION: Efficiency &   use of Monetary Strategy
*==============================================================
use $data 
preserve
	drop if period>16

	macro define controls "sex   duration_lagged   response_t   wrong_ans"		

* Choices consistent with Monetary trade strategy
	gen moneytrade=0
	replace moneytrade=1 if (choice==2 | choice==3 | choice==6 | choice==7)
	bysort treat sessionID game group (ID): egen intensity=mean(moneytrade)

* Collapse by Economy
	collapse profit_partial intensity moneytrade $controls , by (treatment sessionID game group)
	gen efficiency=(profit_partial-4.5)/(7.5-4.5)
	
* GLM regression 
	center sex response_t wrong_ans duration_lagged intensity, inplace  standardize 

	est clear
	
	glm  efficiency c.intensity  ib2.treat##c.game $controls, cluster(sessionID) link(logit) family(binomial) robust nolog 
	margins, dydx(*) at((base) _factor (asobs) $controls ) post
	eststo reg1
		
	estout * using Reg0.tex,  replace cells("b(star fmt(3)) se(par fmt(3))") style(tex) label varlabels(intensity "Monetary Trade"  game Supergame  wrong_ans "Incorrect Answers" _cons Constant male Male  response_t "Response Time"   sex "Prop. males")  collabels(,none) stats(N , labels("N") fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel

restore


*==============================================================
*	  BASELINE TABLE: 	OUTCOMES experienced  by a subject
*==============================================================
use $data
	preserve
	keep if inlist(treat, 2)
	drop if period>16
				
	rename outcome coop
			
	gen gift=0 
	replace gift=1 if coop==1 & transfer==0

	* Unconditional cooperation is compensated with a token
	gen quasi_gift=0 
	replace quasi_gift=1 if (choice==1 & transfer==1) | (choice_o==1 & transfer==-1)


	gen DEF=0
	replace DEF=1 if coop==0 & (choice==0 | choice_o==0)

 	gen fullC=gift if type==1
 	gen fullD=DEF if type==1

	gen coopP=coop if possible==1
	gen tradeP=trade if possible==1
	gen giftP=gift if possible==1

	collapse quasi_gift coop coopP trade* gift* possible fullC fullD spend sell, by(treatment sessionID game group ID)

* Uncover ALTRUISTS and FREE RIDERS
 	replace fullC=cond(fullC>0.99,1,0)
 	replace fullD=cond(fullD>0.99,1,0)

** Experience of the average subject: All meetings
	table game, c(m coop  m trade m gift m possible m quasi_gift) col format(%9.2f) 
	table game, c(m fullC  m fullD) col format(%9.2f) 

** Experience of the average subject:  Only meetings where Monetary Trade was possible
	table game, c(m coopP  m tradeP m giftP) col format(%9.2f) 
	table game, c(m spend  m sell) format(%9.2f)  row

restore



*======================================================================================
* 	 BASELINE TABLE:   Sell,  Spend, Monetary Trade, Gift (by subject, in meetings where trade is POSSIBLE)
*=====================================================================================
use $data
	preserve
	keep if inlist(treat, 2)
	drop if period>16
	drop if type==0
	
	keep if possible==1	
	
	* recode the spend choice for a consumer
	gen newspend=0 if choice_o==5 
	replace newspend=1 if choice_o>5 
	
	* Outcome is a Gift or not
	gen gift=0 
	replace gift=1 if outcome==1 & transfer==0

	collapse sell newspend gift trade, by(sessionID game ID)
	collapse sell newspend gift trade, by(game)
	
	** Frequency of choices
	table game, c(m newspend m sell m trade m gift) format(%9.2f)  
	

restore




*==============================================================
*	  BASELINE FIGURE: 	OUTCOMES experience by a participant in a supergame (all meetings)
*==============================================================
use $data
preserve
	keep if inlist(treat, 2)
	drop if period>16

rename outcome coop
	
gen gift=0 
	replace gift=1 if coop==1 & transfer==0

gen DEF=0
	replace DEF=1 if coop==0 & (choice==0 | choice_o==0)

collapse coop trade gift possible, by(treatment sessionID game group ID)
collapse  coop  gift possible trade (sem) semc=coop  semg=gift (count) n=coop,   by(treatment game)

gen  hi_sem = coop + semc
gen  low_sem = coop - semc
	
gen  hi_semg = gift + semg
gen  low_semg = gift - semg
	
gen position=game
	replace position=game+2 if game==2
	replace position=game+4 if game==3
	replace position=game+6 if game==4
	replace position=game+8 if game==5


tw (bar coop position, sort msymbol(o t)  lpattern(solid  solid) lwidth(medthick medthick )  mcolor(black black )  lcolor(black) color(gs15))    (bar gift position, sort msymbol(o t)  lpattern(solid  solid) lwidth(medthick medthick )  mcolor(black black )  lcolor(black) color(gs8))   		(rcap hi_sem low_sem position, vertical bcolor(black) lwidth(medthin))      (scatter trade position,  connect(l) lpattern(solid)  lwidth(thick) msymbol(o)   mfc(red*0.5) mlc(black) mlw(medthin)  lcolor(red) msiz(large))  (scatter possible  position,  connect(l) lpattern(dash)  lwidth(thick) msymbol(d)   mfc(white) mlc(black) mlw(medthin)  msiz(large))     (rcap hi_semg low_semg position, vertical bcolor(black) lwidth(medthin))  ,      xlabels(0 " "  1 "1"  4  "2"   7 "3"   10 "4"  13 "5"   14" ", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(small) ) ytitle(Relative Frequency) ylabels(0(0.2)1, nogrid)  scale(1.4) graphregion(style(none) color(gs16))  legend(order(1 "Cooperation Occurs"  2 "Gift (made or received)"    4  "Monetary Trade Occurs" 5 "Monetary Trade is Possible " )  ring(0) pos(11) rows(2)  size(small) symxsize(*0.25)  region(lstyle(none))  )      plotregion(margin(zero))   	

 graph export coop-Baseline.eps, as(eps) preview(off) replace 	
	
restore




*=============================================================================
*	BASELINE TREAT  PANEL REGRESSION -- OUTCOMES FOR A PLAYER:  Coop, Trade and Gift  (all meetings)
*=============================================================================
use $data 

*****   ALL meetings  ******
	preserve
	keep if inlist(treat,2)
	drop if period>16

	gen cooperate=outcome

	gen gift=0 
	replace gift=1 if coop==1 & transfer==0

	macro define controls "sex duration_lagged response_t wrong_ans"		

	collapse cooperate  trade possible sell spend gift  $controls, by (treatment sessionID  game ID  )
	center possible response_t wrong_ans duration_lagged, inplace  standardize 

**  PANEL REGRESSION with random effects
	xtset ID game

	est clear
	xtreg  coop possible game  $controls,  re cluster(session)
	eststo reg1

	xtreg  gift possible game $controls,  re cluster(session)
	eststo reg2
	
	xtreg  trade  game  $controls,  re cluster(session)
	eststo reg3

	estout reg1 reg2 reg3  using Reg1.tex,  replace cells("b(star fmt(3)) se(par fmt(3))") style(tex) label varlabels(possible "Mon. Trade Possible" game Supergame  duration "Supergame duration" wrong_ans "Incorrect Answers" _cons Constant response_t "Response Time"   sex "Prop. males")  collabels(,none) stats(N r2_w r2_b r2_o , labels("N"  "R$^2$ within" "R$^2$ between" "R$^2$ overall" ) fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel
	
restore

*****   TRADE-POSSIBLE  meetings  ******
preserve
	keep if inlist(treat,2)
	drop if period>16
	keep if possible==1

	gen cooperate=outcome

	gen gift=0 
	replace gift=1 if coop==1 & transfer==0

	macro define controls "sex duration_lagged response_t wrong_ans"		

	collapse cooperate  trade possible sell spend gift  $controls, by (treatment sessionID game ID)
	center response_t wrong_ans duration_lagged, inplace  standardize 

***  PANEL REGRESSION with random effects
	xtset ID game

	est clear
	xtreg  trade game  $controls,  re cluster(session)
	eststo reg11

	xtreg  gift game  $controls,  re cluster(session)
	eststo reg12
	
	xtreg  spend game   $controls,  re cluster(session)
	eststo reg13
	
	xtreg  sell game $controls,  re cluster(session)
	eststo reg14

	estout * using Reg2.tex,  replace cells("b(star fmt(3)) se(par fmt(3))") style(tex) label varlabels(possible "Mon. Trade Possible" game Supergame  duration "Supergame duration" wrong_ans "Incorrect Answers" _cons Constant response_t "Response Time"   sex "Prop. males")  collabels(,none) stats(N r2_w r2_b r2_o , labels("N" "R$^2$ within" "R$^2$ between" "R$^2$ overall" ) fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel
	
restore



	
***************************************************
*  	OTHER    TREATMENTS    
***************************************************

*====================================================================================================
*	  TABLE: 	OVERVIEW of OUTCOMES by SUPERGAME  (1 obs= 1 SUBJECT in a SUPERGAME)
*====================================================================================================
use $data
	preserve
	keep if inlist(treat, 1, 2, 3, 4, 5, 6, 7)
	drop if period>16
		
	rename outcome coop
			
* Outcome is a Gift or not
	gen gift=0 
	replace gift=1 if coop==1 & transfer==0

* Outcomes in meetings where trade is POSSIBLE
	gen coopP=coop if possible==1
	gen tradeP=trade if possible==1
	gen giftP=gift if possible==1

collapse coop coopP trade* gift* possible spend sell, by(treatment sessionID game group ID)

** All meetings
	table treat game, c(m coop  m trade m gift m possible) col format(%9.2f) 
** Only meetings where Monetary Trade was POSSIBLE 
	table treat game, c(m coopP  m tradeP m giftP) col format(%9.2f) 
	table treat game, c(m spend  m sell) col format(%9.2f) 

restore


*=========================================================================================
*	FIGURE:  SESSIONS  OVERVIEW ----  COOPERATION by SUPERGAME (1 obs= 1 SUBJECT/SUPERGAME) all meetings
*=========================================================================================
use $data
	preserve
	graph drop _all
	keep if inlist(treat, 1,2,3, 4, 5, 6, 7)
	drop if period>16

	gen coop=outcome
	
* Outcome is a Gift or not
	gen gift=0 
	replace gift=1 if coop==1 & transfer==0

	collapse coop trade possible profit_partial gift, by(treatment sessionID game group ID)
	collapse  coop  gift possible trade (sem) semc=coop  semg=gift semt= trade (count) n=coop,   by(treatment game)
	
** Create variables for SMALL SUPPLY  economies (1 token) and LARGE SUPPLY economies (2 tokens)
	local variable " 1 2 3 4 5 6 7"
	
	foreach i of local variable{
	gen coop`i'=coop if treat==`i'
	gen gift`i'=gift if treat==`i'
	gen trade`i'=trade if treat==`i'
	** create the high and low values of the MSE 
	generate hi_sem`i' = coop + semc   if treat==`i' 
	generate low_sem`i' = coop - semc if treat==`i'
	
	generate hi_semg`i' = gift + semg  if treat==`i' 
	generate low_semg`i' = gift - semg  if treat==`i' 
	
	generate hi_semt`i' = trade  + semt  if treat==`i' 
	generate low_semt`i' = trade  - semt  if treat==`i' 
	}

	gen position=game
	replace position=game+2 if game==2
	replace position=game+4 if game==3
	replace position=game+6 if game==4
	replace position=game+8 if game==5

	gen position1=position+0.5
	gen position2=position+0.75


********************************************************
* 	 1-TOKEN TREATMENTS d=-1,0,1,2  and 0 to E[u]=1 Switch TREATMENT (all meetings) 
********************************************************

** FIGURE:  Cooperation (all meetings)
	tw  (scatter coop2 coop3 coop4  coop1 coop7 position, connect(l l l l  l) lcolor(black blue green red black) lw(medthick medthick medthick medthick medthick) msymbol(o s t d o)  lpattern(dash solid solid solid solid)  mfc(black blue green red gs12) mlc(black black black black black ) mlw(medthin medthin medthin medthin medthin)  msiz(medium medlarge medlarge medlarge medlarge ) )  (rcap hi_sem2 low_sem2 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_sem3 low_sem3 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_sem4 low_sem4 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_sem1 low_sem1 position, vertical bcolor(black) lwidth(medthin)) (rcap hi_sem7 low_sem7 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_sem3 low_sem3 position, vertical bcolor(black) lwidth(medthin))   ,   xlabels(1 "1"  4 "2"   7 "3"   10 "4"  13 "5", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(medsmall) ) ytitle(Cooperation) ylabels(0(0.2)1, nogrid)   legend(off) plotregion(margin(zero))   scale(1.4) graphregion(style(none) color(gs16))  aspectratio(1) name(g1)

** 	FIGURE:  Monetary Trade (all meetings)
	tw  (scatter trade2 trade3 trade4 trade1 trade7 position,  connect(l l l l  l) lcolor(black blue green red black) lw(medthick medthick medthick medthick medthick) msymbol(o s t d o)  lpattern(dash solid solid solid solid)  mfc(black blue green red gs12) mlc(black black black black black ) mlw(medthin medthin medthin medthin medthin)  msiz(medium medlarge medlarge medlarge medlarge ) ) (rcap hi_semt2 low_semt2 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_semt3 low_semt3 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_semt4 low_semt4 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_semt1 low_semt1 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_semt7 low_semt7 position, vertical bcolor(black) lwidth(medthin)),   xlabels(1 "1"  4 "2"   7 "3"   10 "4"  13 "5", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(medsmall) ) ytitle(Monetary Trade) ylabels(0(0.2)1, nogrid)   legend(order(1 "Fiat: u=0"     2 "Reward: u=1"  3 "Reward2: u=2" 4 "Penalty: u=-1" 5 "Switch: u=0 to E[u}=1")  ring(0) pos(11) rows(4)  size(small) symxsize(*0.6)  region(lstyle(none))  )       plotregion(margin(zero))   scale(1.4)  graphregion(style(none) color(gs16)) aspectratio(1)  name(g2)	
	
	gr combine g1 g2, ycommon xsize(2) ysize(1)  rows(1) graphregion(color(white)fcolor(white)) plotregion(margin(zero)) imargin(medlarge) scale(1.3)   
 	graph export coop-1Token.eps, as(eps) preview(off) replace 
	
********************************************
*     2-TOKEN (MIX and Fiat2)  and Fiat 
********************************************
	graph drop _all

** 	FIGURE:  Cooperation (all meetings)
	tw  (scatter coop2 coop5 coop6   position, connect(l l l l  l) lcolor(black blue green red black) lw(medthick medthick medthick medthick medthick) msymbol(o s t d o)  lpattern(dash solid solid solid solid)  mfc(black blue green red gs12) mlc(black black black black black ) mlw(medthin medthin medthin medthin medthin)  msiz(medium medlarge medlarge medlarge medlarge ) )   (rcap hi_sem2 low_sem2 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_sem5 low_sem5 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_sem6 low_sem6 position, vertical bcolor(black) lwidth(medthin)) ,   xlabels(1 "1"  4 "2"   7 "3"   10 "4"  13 "5", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(medsmall) ) ytitle(Cooperation) ylabels(0(0.2)1, nogrid)   legend(off)    plotregion(margin(zero))   scale(1.4) graphregion(style(none) color(gs16))  	name(g1)
					
** 	FIGURE:  Monetary Trade (all meetings)
	tw  (scatter trade2 trade5 trade6     position, connect(l l l l  l) lcolor(black blue green red black) lw(medthick medthick medthick medthick medthick) msymbol(o s t d o)  lpattern(dash solid solid solid solid)  mfc(black blue green red gs12) mlc(black black black black black ) mlw(medthin medthin medthin medthin medthin)  msiz(medium medlarge medlarge medlarge medlarge ) )   (rcap hi_semt2 low_semt2 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_semt5 low_semt5 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_semt6 low_semt6 position, vertical bcolor(black) lwidth(medthin)),   xlabels(1 "1"  4 "2"   7 "3"   10 "4"  13 "5", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(medsmall) ) ytitle(Monetary Trade) ylabels(0(0.2)1, nogrid)   legend(order(1 "Fiat: u=0"  2 "Fiat2: u=0 +  u=0"  3 "Mix: u=0 + u=2")  ring(0) pos(11) rows(4)  size(small) symxsize(*0.6)  region(lstyle(none))  )      plotregion(margin(zero))   scale(1.4)  graphregion(style(none) color(gs16))  name(g2)	
		
gr combine g1 g2, ycommon xsize(2) ysize(1)  rows(1) graphregion(color(white)fcolor(white)) plotregion(margin(zero)) imargin(medlarge) scale(1.3)   
 	
 graph export coop-2Token.eps, as(eps) preview(off) replace 
		
restore

*===========================================================
*		OTHER TREATMENTS   - STATISTICAL ANALYSIS ---  OUTCOMES
*===========================================================
use $data 
preserve
	keep if inlist(treat, 1, 2, 3, 4, 5, 6, 7)
	drop if period>16
	
	gen coop=outcome
			
	collapse coop  trade, by(treatment sessionID game ID)
        collapse coop trade (count) N=coop, by(treat sessionID)
	
** Two-sided Wilcoxon-Mann Whitney ranksum test with exact statistics
		dis "==     COOP    =="
	gen temp=coop
	ranksumex temp if inlist(treatment, 1,2), by(treatment)
	ranksumex temp if inlist(treatment, 2,3), by(treatment)
	ranksumex temp if inlist(treatment, 2,4), by(treatment)
	drop temp

		dis "==     MONETARY TRADE  =="
	gen temp=trade
	ranksumex temp if inlist(treatment, 1,2), by(treatment)
	ranksumex temp if inlist(treatment, 2,3), by(treatment)
	ranksumex temp if inlist(treatment, 2,4), by(treatment)
	drop temp

restore




*======================================================================================
* 	ALL TREATMENTS -- Table: 	Sell,  Spend, Monetary Trade, Gift (by subject, meetings where trade is POSSIBLE)
*=====================================================================================
use $data
	preserve
	drop if period>16
	drop if type==0
	
	by treat: count 
	keep if possible==1	
	by treat: count 
	
	* recode the spend choice for a consumer
	gen newspend=0 if choice_o==5 
	replace newspend=1 if choice_o>5 
	
	* Outcome is a Gift or not
	gen gift=0 
	replace gift=1 if outcome==1 & transfer==0
	
	collapse sell newspend gift trade, by(treat sessionID game ID)
	collapse sell newspend gift trade, by(treatment)
	
	** Frequency of choices
	table treat, c(m newspend m sell m trade m gift) format(%9.2f)  
	

restore



*========================================================================
*	PANEL REGRESSIONS -- 1- TOKEN ECONOMIES (all meetings)
*========================================================================
use $data 
preserve
	keep if inlist(treat,1,2,3,4)
	drop if period>16

	gen cooperate=outcome

** Monetary trade strategy selection
	gen moneytrade=0
	replace moneytrade=1 if (choice==2 | choice==3 | choice==6 | choice==7)

* Outcome is a Gift or not
	gen gift=0 
	replace gift=1 if coop==1 & transfer==0
	
	macro define controls "sex duration_lagged response_t wrong_ans"		

	collapse cooperate  trade profit_partial possible sell spend gift  moneytrade $controls, by (treatment sessionID game ID)
	center possible  response_t wrong_ans duration_lagged, inplace  standardize 

***  REGRESSION:  Only Supergame 1
	est clear
	reg  coop possible   ib2.treat  $controls if game==1,  cluster(session)
	reg  trade ib2.treat   $controls if game==1,  cluster(session)

***  PANEL REGRESSION with random effects 
	est clear
	xtset ID game
	
	xtreg  coop possible  ib2.treat##c.game  $controls,  re cluster(session)
	eststo reg1
	test c.game + 1.treatment#c.game = 0
	test c.game+3.treatment#c.game = 0 
	test c.game+4.treatment#c.game = 0 

	xtreg  gift possible  ib2.treat##c.game  $controls,  re cluster(session)
	eststo reg2
	test c.game + 1.treatment#c.game = 0
	test c.game+3.treatment#c.game = 0 
	test c.game+4.treatment#c.game = 0 
	
	xtreg  trade ib2.treat##c.game $controls,  re cluster(session)
	eststo reg3
	test c.game + 1.treatment#c.game = 0
	test c.game+3.treatment#c.game = 0 
	test c.game+4.treatment#c.game = 0 
	
	estout * using Reg3.tex,  replace cells("b(star fmt(3)) se(par fmt(3))") style(tex) label varlabels(possible "Trade Possible"  game Supergame  duration "Supergame duration" wrong_ans "Incorrect Answers" _cons Constant male Male  response_t "Response Time"   sex "Prop. males" game2 "Supergame$^2$")  collabels(,none) stats(N r2_w r2_b r2_o , labels("N" "R$^2$ within" "R$^2$ between" "R$^2$ overall" ) fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel

restore
								     			


*============================================================================================================
*	1-TOKEN TREATMENTS -  MUTINOMIAL LOGIT (PRODUCER'S choices) & LOGIT (CONSUMER'S CHOICES & NO-TRADE MEETINGS)
*============================================================================================================
use $data 
preserve
	keep if inlist(treat,1, 2, 3, 4)
	keep if period<17

	 macro define controls "sex response_t wrong_ans"		

	collapse  choice $controls , by (treatment sessionID game type ID possible period)
 	center  response_t wrong_ans, inplace  standardize 

** MULTINOMIAL LOGIT: Choice of Producers 
	est clear 	
	macro define controls "response_t  wrong_ans    i.sex"	 
	
	mlogit choice  ib2.treat##c.game i.period $controls if type==1 & possible==1, base(0)  cluster(session)
	eststo reg1

	** Marginal effects by choice **
	local i "0 1 2 "
	foreach i in 0 1 2  {
	quietly margins, dydx(*) at((means) _all (base) _factor) predict(outcome(`i')) post
	eststo Choice`i'
	estimates restore reg1
	}

	estout Choice0 Choice1 Choice2 using Reg4.tex, replace cells("b(star fmt(3)) se(par fmt(3))") style(tex)  stats(N, labels("N")  fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) varlabels(1.treatment "Penalty"  3.treatment "Reward" 4.treatment "Reward2"  game Supergame  wrong_ans "Incorrect Answers" _cons Constant male Male response_t "Response Time" 1.sex "Male" ) 

	eststo drop Choice0 Choice1 Choice2

	** Tests on estimated marginal effects **
	estimates restore reg1
	margins, dydx(*) at((means) _all (base) _factor) post
		
	test [1.treatment]1._predict =[3.treatment]1._predict 
	test [1.treatment]2._predict =[3.treatment]2._predict 
	test [1.treatment]3._predict =[3.treatment]3._predict 

	test [1.treatment]1._predict =[4.treatment]1._predict 
	test [1.treatment]2._predict =[4.treatment]2._predict 
	test [1.treatment]3._predict =[4.treatment]3._predict 

	test [3.treatment]1._predict =[4.treatment]1._predict 
	test [3.treatment]2._predict =[4.treatment]2._predict 
	test [3.treatment]3._predict =[4.treatment]3._predict 


**==== LOGIT:  CHOICES of CONSUMERS and PRODUCERS 
	est clear 
	macro define controls "response_t  wrong_ans   sex"	

	** Consumers (meetings where Trade is Possible): two choices here (keep, spend)
	gen DEP=choice-5 if type==0
	logit DEP ib2.treat##c.game i.period $controls if type==0 & possible==1, cluster(session)
	margins, dydx(*) at((base) _factor (asobs) $controls) post
	eststo reg2
	test 1.treatment=3.treatment
	test 1.treatment=4.treatment
	test 3.treatment=4.treatment


	** Producers (Trade Impossible): two choices here, D and C
	logit choice   ib2.treat##c.game i.period $controls if type==1 & possible==0, cluster(session)
	margins, dydx(*) at((base) _factor (asobs) $controls) post
	eststo reg3
	test 1.treatment=3.treatment
	test 1.treatment=4.treatment
	test 3.treatment=4.treatment
	
	estout reg2 reg3    using Reg5.tex,  replace cells("b(star fmt(3)) se(par fmt(3))") style(tex) label varlabels(1.treatment "Penalty"  3.treatment "Benefit" 4.treatment "Benefit2"  game Supergame  wrong_ans "Incorrect Answers" _cons Constant male Male response_t "Response Time" 1.sex "Male") collabels(,none) stats(N, labels("N"  ) fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel	

restore


*===========================================================
*	FIGURE:  2 TOKEN ECONOMIES & SWITCH -- SESSIONS  OVERVIEW
*===========================================================
use $data
	preserve
	graph drop _all
	keep if inlist(treat,  2,  3, 5, 6, 7)
	drop if period>16

	gen coop=outcome
	
	gen gift=0 
	replace gift=1 if coop==1 & transfer==0

	collapse coop trade possible gift, by(treatment sessionID game group ID)
	collapse  coop  gift possible trade (sem) semc=coop  semg=gift semt= trade (count) n=coop,   by(treatment game)
	
	local variable " 2  3 5 6 7"
	
	foreach i of local variable{
	gen coop`i'=coop if treat==`i'
	gen gift`i'=gift if treat==`i'
	gen trade`i'=trade if treat==`i'
	** create the high and low values of the MSE 
	generate hi_sem`i' = coop + semc   if treat==`i' 
	generate low_sem`i' = coop - semc if treat==`i'
	
	generate hi_semg`i' = gift + semg  if treat==`i' 
	generate low_semg`i' = gift - semg  if treat==`i' 
	
	generate hi_semt`i' = trade  + semt  if treat==`i' 
	generate low_semt`i' = trade  - semt  if treat==`i' 
	}

	gen position=game
	replace position=game+2 if game==2
	replace position=game+4 if game==3
	replace position=game+6 if game==4
	replace position=game+8 if game==5

	gen position1=position+0.5
	gen position2=position+0.75

	
	graph drop _all


*** 	FIGURE:  Cooperation in 2-TOKEN TREATMENTS d=0, 0+0, 0+2
	tw  (scatter coop2 coop5 coop6 position, connect(l l l l  l) lcolor(black blue green red orange) lw(medthick medthick medthick medthick) msymbol(o s t d)  lpattern(solid solid solid dash dash)  mfc(gs12 blue green red) mlc(black black black black ) mlw(medthin medthin medthin)  msiz(large large large large) )  (rcap hi_sem2 low_sem2 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_sem5 low_sem5 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_sem6 low_sem6 position, vertical bcolor(black) lwidth(medthin)) ,   xlabels(1 "1"  4 "2"   7 "3"   10 "4"  13 "5", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(medsmall) ) ytitle(Cooperation) ylabels(0(0.2)1, nogrid)   legend(off)    plotregion(margin(zero))   scale(1.4) graphregion(style(none) color(gs16))  	name(g1)
				

*** 	FIGURE:  Monetary Trade in 2-TOKEN TREATMENTS d=0, 0+0, 0+2
	tw  (scatter trade2 trade5 trade6 position, connect(l l l  l l ) lcolor(black blue green red orange) lw(medthick medthick medthick medthick medthick) msymbol(o s t d)  lpattern(solid solid solid dash dash)  mfc(gs12 blue green red) mlc(black black black black ) mlw(medthin medthin medthin)  msiz(large large large large) )  (rcap hi_semt2 low_semt2 position, vertical bcolor(black) lwidth(medthin))  (rcap hi_semt5 low_semt5 position, vertical bcolor(black) lwidth(medthin))   (rcap hi_semt6 low_semt6 position, vertical bcolor(black) lwidth(medthin))   ,   xlabels(1 "1"  4 "2"   7 "3"   10 "4"  13 "5", labs(medsmall))    yscale(range(0 1)) xtitle(Supergame, size(medsmall) ) ytitle(Monetary Trade) ylabels(0(0.2)1, nogrid)   legend(order(1 "Fiat: u=0"  2 "Fiat2: u=0+u=0"  3 "Mix: u=0+u=2")  ring(0) pos(11) rows(4)  size(small) symxsize(*0.6)  region(lstyle(none))  )      plotregion(margin(zero))   scale(1.4)  graphregion(style(none) color(gs16))  name(g2)	
			
	gr combine g1 g2, ycommon xsize(2) ysize(1)  rows(1) graphregion(color(white)fcolor(white)) plotregion(margin(zero)) imargin(medlarge) scale(1.3)   
 	 	
 	graph export coop-2Token.eps, as(eps) preview(off) replace 
		
restore



*=====================================================
*	PANEL REGRESSIONS -- 2- TOKEN ECONOMIES (all meetings) 
*=====================================================
use $data
preserve
	keep if inlist(treat, 2,5,6)
	drop if period>16

	gen cooperate=outcome

	gen gift=0 
	replace gift=1 if coop==1 & transfer==0
		
	macro define controls "sex duration_lagged response_t wrong_ans"		

	collapse cooperate trade possible gift  $controls, by (treatment sessionID game ID)
	center possible  response_t wrong_ans duration_lagged, inplace  standardize 

*****  LINEAR REGRESSION:  only supergame 1
	est clear
	
	reg  coop possible  ib2.treat  $controls if game==1,  cluster(session)
	reg  trade ib2.treat  $controls if game==1,  cluster(session)

*****  PANEL REGRESSION with random effects (all supergames)
	est clear		
	xtset ID game
	
	xtreg  coop c.possible   ib2.treat##c.game  $controls,  re cluster(session)
	eststo reg1
	test c.game+5.treatment#c.game = 0 
	test c.game+6.treatment#c.game = 0 

	xtreg  gift c.possible   ib2.treat##c.game   $controls,  re cluster(session)
	eststo reg2
	test c.game+5.treatment#c.game = 0 
	test c.game+6.treatment#c.game = 0 

	xtreg  trade ib2.treat##c.game   $controls,  re cluster(session)
	eststo reg3
	test c.game+5.treatment#c.game = 0 
	test c.game+6.treatment#c.game = 0 

	estout * using Reg6.tex,  replace cells("b(star fmt(3)) se(par fmt(3))") style(tex) label varlabels(possible "Trade Possible" duration "Supergame duration" wrong_ans "Incorrect Answers" _cons Constant male Male  response_t "Response Time"   sex "Prop. males")  collabels(,none) stats(N r2_w r2_b r2_o , labels("N" "R$^2$ within" "R$^2$ between" "R$^2$ overall" ) fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel

	xtreg  possible ib2.treat##c.game  $controls,  re cluster(session)
	test c.game+5.treatment#c.game = 0 
	test c.game+6.treatment#c.game = 0 

restore



*============================================================================
*	  TABLE: 	MIX TREATMENT -- DISTRIBUTION OF CHOICES BASED ON TOKEN HOLDINGS
*============================================================================
use $data
	preserve
	keep if inlist(treat, 6)
	drop if period>16
	drop if type==0
	
	rename outcome coop
	
	* balanceA=Dividend tokens
	* balanceB=PLAIN tokens
	
	
	* Define balances 0,1,2 types
	gen new_balance_o=0 if  balanceB_o==0 & balanceA_o==0
	replace new_balance_o=1 if balanceB_o>0 & balanceA_o==0
	replace new_balance_o=2 if balanceB_o ==0 & balanceA_o>0
	replace new_balance_o=3 if balanceB_o >0 & balanceA_o >0
	
	label define bal    0 "None"      1 "Plain only"       2  "Soph. only"      3 "Both tokens" 
	label values new_balance_o bal

	* Percentage  of observations 
	groups(new_balance_o)
	
	** Distribution of choices depending on consumer's holdings
	tabulate new_balance_o choice_o, row nofreq
	
	tabulate new_balance_o choice, row nofreq
	

restore






*======================================================
*	2-TOKEN ECONOMIES  MUTINOMIAL LOGIT (individual level) 
*======================================================
use $data 
	preserve
	keep if inlist(treat, 2, 5, 6)
	keep if period<17
	keep if type==1

	 macro define controls "sex response_t wrong_ans"		
	
** Outcome for a producer is NEWoutcome=0,1,2,3 if   D, Failed trade, C, monetary trade  [choice=0,1,2, 3 = D, C, C for d-token, C for fiat]
	gen NEWoutcome=0 if choice==0
	replace NEWoutcome=1 if outcome==0 & choice>0
	replace NEWoutcome=2 if outcome==1 & choice==1
	replace NEWoutcome=3 if outcome==1 & choice>1

	
	collapse  choice NEWoutcome $controls , by (treatment sessionID game type ID possible period)
	center  response_t wrong_ans, inplace  standardize 

** MULTINOMIAL LOGIT
	est clear 
	macro define controls "response_t  wrong_ans    i.sex"	 
	
	mlogit NEWoutcome   ib2.treat##c.game i.period $controls if type==1 & possible==1, base(0)  cluster(session)
	eststo reg1

** Marginal effects by choice
	local i "0 1 2 3"
	foreach i in 0 1 2 3{
	quietly margins, dydx(*) at((means) _all (base) _factor) predict(outcome(`i')) post
	eststo Choice`i'
	estimates restore reg1
	}

	estout Choice0 Choice1 Choice2  Choice3 using Reg7.tex, replace cells(b(star fmt(3)) se(par fmt(3))) style(tex)  stats(N, labels("N")  fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) varlabels(5.treatment "Fiat2" 6.treatment "Mix" game Supergame  wrong_ans "Incorrect Answers" _cons Constant male Male response_t "Response Time" 1.sex "Male" ) 

	eststo drop Choice0 Choice1 Choice2 Choice3

	** Now do the tests on estimated marginal effects
	estimates restore reg1
	margins, dydx(*) at((means) _all (base) _factor) post
		
** ARE THERE DIFFERENT CHOICES ACROSS TREATMENTS 5 and 6?
	test [5.treatment]1._predict =[6.treatment]1._predict 
	test [5.treatment]2._predict =[6.treatment]2._predict 
	test [5.treatment]3._predict =[6.treatment]3._predict 
	test [5.treatment]4._predict =[6.treatment]4._predict 
	
restore




*====================================
*	SWITCH vs FIAT: PANEL REGRESSIONS (all supergames)
*====================================
use $data
preserve
	keep if inlist(treat, 2,  7)
	drop if period>16

	gen cooperate=outcome

	gen gift=0 
	replace gift=1 if coop==1 & transfer==0
		
	macro define controls "sex duration_lagged response_t wrong_ans"		

	collapse cooperate  trade possible gift spend sell $controls, by (treatment sessionID game ID)
	
	table treat game if game<3, c(m cooper m trade m gift) col  format(%9.2f) 
	table treat game if game>2, c(m cooper m trade m gift) col  format(%9.2f) 
	
	table treat game if game>2, c(m spend m sell) col  format(%9.2f) 
	
	center possible response_t wrong_ans duration_lagged, inplace  standardize 

*****  REGRESSIONS:  Panel regressions with random effects
	est clear
	xtset ID game
	
	gen game3_5=(game>2)

	xtreg  coop possible  ib2.treat##i.game3_5 $controls ,  re cluster(session)
	eststo reg1
	test 1.game3_5 + 7.treatment#1.game3_5 = 0 
	
	
	xtreg  trade ib2.treat##i.game3_5  $controls ,  re cluster(session)
	eststo reg2
	test 1.game3_5 + 7.treatment#1.game3_5 = 0 
	
restore

*======================================================
*	SWITCH vs REWARD in supergames 3-5: PANEL REGRESSIONS 
*======================================================
use $data
preserve
	keep if inlist(treat, 3, 7)
	drop if period>16
	keep if game>=3

	gen cooperate=outcome

	gen gift=0 
	replace gift=1 if coop==1 & transfer==0
		
	macro define controls "sex duration_lagged response_t wrong_ans"		

	collapse cooperate  trade possible gift spend sell $controls, by (treatment sessionID game ID)
	
	center possible response_t wrong_ans duration_lagged, inplace  standardize 

*****  REGRESSIONS:  Panel regressions with random effects
	xtset ID game
	
	xtreg  coop possible  ib3.treat $controls ,  re cluster(session)
	eststo reg3
			
	xtreg  trade ib3.treat   $controls ,  re cluster(session)
	eststo reg4
		
restore


	estout * using Reg8.tex,  replace cells(b(star fmt(3)) se(par fmt(3))) style(tex) label varlabels(game Supergame  wrong_ans "Incorrect Answers" _cons Constant male Male  response_t "Response Time"   sex "Prop. males")  collabels(,none) stats(N r2_w r2_b r2_o , labels("N" "R$^2$ within" "R$^2$ between" "R$^2$ overall" ) fmt(0 3)) prefoot(\hline) starlevels(* 0.10 ** 0.05 *** 0.01) posthead(\hline) margin(p) nobaselevel
	





*====================================================================
*	  TABLE: 	DISTRIBUTION OF TOKENS ACCROSS MEETINGS -- ALL TREATMENTS
*====================================================================
use $data
	preserve
*	keep if inlist(treat, 1, 2, 3, 4, 5, 6, 7)
	drop if period>16
	drop if type==0
	
	rename outcome coop
	
	* In how many meetings one of the participants had 3 or more tokens?
	bysort treat: tab balance balance_o if (balance>=2 | balance_o>=2)			
	
	* Define balances 0,1,2+
	gen new_balance_o=balance_o  if balance_o<2
	replace new_balance_o=2 if balance_o>=2
	
	gen new_balance=balance  if balance<2
	replace new_balance=2 if balance>=2
	
** Distribution of meetings according to token holdings **
	by treat: tabulate new_balance new_balance_o, cell nofreq 

** Distribution of cooperation in meetings according to token holdings **
	foreach i in 1 2 3 4 5 6 7 {
	 tabout new_balance new_balance_o using meetings_coop_`i'.txt if treat==`i', sum cells(mean coop) format(2) clab(_ _ _)  layout(rb) h3(nil) replace style(tex) bt font(bold) cl1(2-6) topstr(11cm)
	}

*** Coarser view
	drop new_balance*
	
	gen new_balance_o=balance_o  if balance_o==0
	replace new_balance_o=1 if balance_o>=1
	
	gen new_balance=balance  if balance==0
	replace new_balance=1 if balance>=1

** Distribution of meetings according to token holdings **
	by treat: tabulate new_balance new_balance_o, cell nofreq 
	by treat: tabulate new_balance new_balance_o, col  nofreq 

	foreach i in 1 2 3 {
	 tabout new_balance new_balance_o using meetings_coop_`i'.txt if treat==`i', sum cells(mean coop) format(2) clab(_ _ _)  layout(rb) h3(nil) replace style(tex) bt font(bold) cl1(2-6) topstr(11cm)
	}
restore
	

erase temp_data.dta
