**********************************************************************
* 		Run this to create the data file Multi_Money-data.dta using Excel  data
**********************************************************************
clear all
capture log close
cd C:\temp\DATA\DataCleaning
log using "Data_Cleaning`c(current_date)'.log", replace

set more 1
set scheme sol
set autotabgraphs on  

			
*** TREATMENTS  ***
** One Money **
* Treatment  1 (3 sessions) = -1 dividend (allsupergames)
* Treatment  2 (3 sessions) = 0 dividend (all supergames)
* Treatment  3 (3 sessions) = 1 dividend (all supergames)
* Treatment  4 (3 sessions) = 2 dividend (all supergames)

** Two Monies **
* Treatment  5  (3 sessions) =2 Tickets d=0 in all blocks
* Treatment  6 (3 sessions) = 2  Tickets d=0 & d=2 in all supergames

** Switch **
* Treatment  7 (3 sessions) =  1 d=0 ticket in games 1-2 and 1 d>0 ticket in games 3-5, w/ random d=0, 2 w/ equal prob


* Import SUBJECTS + QUIZ data from .xlsx files Session#Treatment# and add treatment variable  k=Treatment i=Session

	forvalues k=1/1{
		forvalues i=1/3{
			import excel using Session`i'T`k'.xlsx, clear
			gen Treatment =`k'
			gen Session=`i'
			if `i'>1 append using "mainfile"
			save "mainfile", replace
		}
	}

	forvalues k=2/7{
		forvalues i=1/3{
			import excel using Session`i'T`k'.xlsx, clear
			gen Treatment =`k'
			gen Session=`i'
			if `i'>1 | `k'>1 append using "mainfile"
			save "mainfile", replace
		}
	}


* Import SURVEY data from .xlsx files SurveySession#Treatment# and add treatment variable
	forvalues k=1/1{
		forvalues i=1/3{
			import excel using SurveySession`i'T`k'.xlsx, clear
			gen Treatment =`k'
			gen Session=`i'
			if `i'>1 append using "survey"
			save "survey", replace
		}
	}

* Import SURVEY data from .xlsx files SurveySession#Treatment# and add treatment variable
	forvalues k=2/7{
		forvalues i=1/3{
			import excel using SurveySession`i'T`k'.xlsx, clear
			gen Treatment =`k'
			gen Session=`i'
			if `i'>1 | `k'>1 append using "survey"
			save "survey", replace
		}
	}



*======================================================
* 		Cleaning SUBJECT Data
*======================================================
	clear all
	capture log close
	cd C:\temp\DATA\DataCleaning
	use mainfile.dta, clear

*Date of session (in column A)
	gen ymd=substr(A,1,6)
	destring ymd, replace

*Time of session (in column A)
	gen hm=substr(A,8,11)
	destring hm, replace

	sort ymd hm
	order Session
	drop A

	sort C
	drop if C != "subjects"
	gsort -D
	keep if B==2

	gen temp =_n
	drop if D=="Period" & temp!=1

	drop B
	drop BB - DM
	
* Replace headers with the strings in the first row (these columns headers will now be the variable names)
	capture 
	foreach var of varlist  C - BA {
	label variable `var' "`=`var'[1]'"
	rename `var' `=`var'[1]'
	}

	drop if temp==1

	gen dividend=aTicketsDividend
	drop aTicketsDividend

	destring Period - dividend, replace
	drop temp subjects

*Delete unneeded variables
	drop bTicketsDividend other_n other_x my_x my_n Participate treatment profitY* profitZ* randM numberPair idInGroup 

	order Treatment Session Subject
	save Multi_Money-data.dta, replace


*======================================================
* 		Cleaning QUIZ Data
*======================================================
	clear all
	capture log close
	cd C:\temp\DATA\DataCleaning
	use mainfile.dta, clear

	gen ymd=substr(A,1,6)
	destring ymd, replace

	gen hm=substr(A,8,11)
	destring hm, replace

	sort ymd hm
	order Session
	drop A

	keep if C== "subjects" & B==1
	gsort -D

	gen temp =_n
	drop if D=="Period" & temp!=1

	drop B

	gen ResponseTime1=X
	gen ResponseTime2=Y
	gen ResponseTime3=Z
	gen ResponseTime4=AA
	gen ResponseTime5=AB
	gen ResponseTime6=AC
	gen ResponseTime7=AD
	gen ResponseTime8=AE
	gen ResponseTime9=AF
	gen ResponseTime10=AG
	
	drop N -  CC

	capture 
	foreach var of varlist  C - M {
	label variable `var' "`=`var'[1]'"
	rename `var' `=`var'[1]'
	}

	drop if temp==1

	destring Period - RightAnswers, replace
	destring  ResponseTime1 - ResponseTime10, replace

	gen ResponseTime=0
	forvalues i=1/10{
		gen test=ResponseTime`i'
		replace ResponseTime=test+ResponseTime
		drop test
	}

	keep Session Treatment Subject ResponseTime RightAnswers

	order Treatment Session Subject

	save quiz.dta, replace

	
*======================================================
* 		Merge QUIZ and SUBJECTS Data
*======================================================	
	clear all
	capture log close
	cd C:\temp\DATA\DataCleaning
	use Multi_Money-data.dta, clear
	sort Treatment Session Subject
	 save Multi_Money-data2.dta, replace

	 use quiz.dta
	 sort Treatment Session Subject
	 save quiz2, replace
 
	use Multi_Money-data2
	merge m:1 Treatment Session Subject using quiz2
	
	egen temp=min(_merge)

	if temp==3 {
		drop _merge 
		}
	
	drop temp
	save Multi_Money-data.dta, replace

	
*======================================================
* 		Cleaning SURVEY Data
*======================================================
	clear all
	capture log close
	cd C:\temp\DATA\DataCleaning
	use survey.dta, clear

	gen ymd=substr(A,1,6)
	destring ymd, replace

	gen hm=substr(A,8,11)
	destring hm, replace

	sort ymd hm
	order Treatment Session
	drop A C

	gsort -B

	gen temp =_n
	drop if D=="sex" & temp!=1

	capture 
	foreach var of varlist  B - P {
	label variable `var' "`=`var'[1]'"
	rename `var' `=`var'[1]'
	}

	drop if temp==1
	drop temp

	destring Subject, replace
	destring  timeLeisure - timeWork, replace
	destring ymd, replace

	encode sex, generate(sex2)
	drop sex
	gen sex=sex2
*Here male=1 is a female and male=2 is a male, since sex is in alphabetical order
	drop sex2
	replace sex=sex-1
	label define sexl 0 "F" 1 "M" 
	label values sex sexl
	label variable  sex "sex (F=0)"

	encode instructions, generate(instr2)
	drop instructions
	gen instructions=instr2
*Here instructions=2 is "instructionrs are clear" and 1 is "instructions not clear", since instructions is in alphabetical order
	drop instr2
	replace instructions=instructions-1
	label define instrl 0 "No" 1 "Yes" 
	label values instructions instrl
	label variable  instructions "Instructions clarity (1=clear)"

*==Risk:  0 "Less than 200"   1="200 to 400" 2="400 to 600 " 3="600 to 800 "
	encode risk, generate(risk2)
	recode risk2 (4=0)
	drop risk
	gen risk=risk2
	drop risk2
	label define riskl 0 "< $200"   1 "$200 - $400" 2 "$400 - $600 " 3 "$600 - $800 "
	label values risk riskl
	label variable  risk "Riks choice"

*==Introvert   (answers are "in groups and like working in them" and "being alone and like things I can do on my own")  
	encode introvert, generate(temp2)
	drop introvert
	gen introvert=temp2-1
	drop temp2
	label drop temp2
	label variable  introvert "Introvert (0=Yes 1=No)"

*==Feeling   (answers are "with my head and want to be fair" OR "with my heart and want to be compassionate")
	encode feeling, generate(temp2)
	drop feeling
	gen emotional=temp2-1
	drop temp2
	label drop temp2
	label variable  emotional "Emotional (Head=0, Heart=1)"

*==Intuition (answers are "actual experience more than impressions"  OR "impressions more than actual experience")
	encode intuition, generate(temp2)
	drop intuition
	gen spontaneous=temp2-1
	drop temp2
	label drop temp2
	label variable  spontaneous "Spontaneous (0=No 1-Yes)"


*==Create categories of majors  
	gen temp = "Bus-Econ"  if strpos(major, "siness") | strpos(major, "arketing") | strpos(major, "Econ")  | strpos(major, "econ") | strpos(major, "Acco") | strpos(major, "ccounting")  | strpos(major, "inance") 
	
	replace temp="Art"  if temp=="" &  strpos(major, "Art") | strpos(major, "art") | strpos(major, "usic")  | strpos(major, "ilm") | strpos(major, "screen") | strpos(major, "heater") | strpos(major, "reative") | strpos(major, "dance") | strpos(major, "Dance") | strpos(major, "cting") | strpos(major, "creen") | strpos(major, "erform") | strpos(major, "esign") | strpos(major, "heatre") 
	
	replace temp="Science"  if temp=="" &   strpos(major, "Bio") | strpos(major, "bio") | strpos(major, "omputer")  | strpos(major, "comp") | strpos(major, "sci") | strpos(major, "Sci") | strpos(major, "inesiology") | strpos(major, "kines") | strpos(major, "hysics") | strpos(major, "gineering") | strpos(major, "pharma") | strpos(major, "Pharma") | strpos(major, "matics") | strpos(major, "SIOLOGY")
	
	replace temp="LibArts"  if temp=="" &   strpos(major, "Psy") | strpos(major, "psy") | strpos(major, "ommunicatio")  | strpos(major, "nglish") | strpos(major, "iterature") | strpos(major, "writ") | strpos(major, "Writ") | strpos(major, "roduction") | strpos(major, "story") | strpos(major, "ociology") | strpos(major, "anguage") | strpos(major, "elevision") | strpos(major, "ublic") | strpos(major, "education") | strpos(major, "Education") | strpos(major, "Advert") | strpos(major, "advert") | strpos(major, "philo") | strpos(major, "Philo") | strpos(major, "train") | strpos(major, "Train") | strpos(major, "Peace") | strpos(major, "peace") | strpos(major, "tudies") | strpos(major, "panish") | strpos(major, "anguage") | strpos(major, "ournalism")

	replace temp="Other"  if temp=="" 
	
	encode temp, gen(major_set)
	label variable major_set "Major"

	drop temp major

	graph drop _all


*==Create categories of comments (indicator for "if cell contains the word or phrase") -- Command below creates temp= if the variable comments (which is a string) contains the text inserted 

	gen temp = "Like"  if strpos(comments, "fun") | strpos(comments, "enjoy") | strpos(comments, "nteresting") | strpos(comments, "great") | strpos(comments, "lol") 
	
	replace temp="Boring"  if temp=="" & strpos(comments, "boring") | strpos(comments, "slow") | strpos(comments, "faster") | strpos(comments, "repetit") | strpos(comments, "fewer") 
	
	replace temp="Dislike"  if temp=="" &   strpos(comments, "hate") | strpos(comments, "dumb") 
	
	replace temp="Nothing"  if temp=="" &   strpos(comments, "N/A") | strpos(comments, "none") | strpos(comments, "n/a") | strpos(comments, ".") | strpos(comments, "None") 

	replace temp="Other"  if temp=="" 
	
	encode temp, gen(comments_set)
	label variable comments_set "Comments"

	drop temp comments

	save survey-data.dta, replace


*======================================================
* 		Merge QUIZ+SUBJECTS Data with SURVEY Data
*======================================================	
	clear all
	capture log close
	cd C:\temp\DATA\DataCleaning

	use Multi_Money-data.dta, clear
	sort Treatment Session Subject
	 save Multi_Money-data2.dta, replace

	 use survey-data.dta
	 sort Treatment Session Subject
	 save survey2, replace
 
	use Multi_Money-data2.dta
	merge m:1 Treatment Session Subject using survey2

	egen temp=min(_merge)

	if temp==3 {
		drop _merge
		drop temp
		}

	save Multi_Money-data.dta, replace

	erase quiz.dta
	erase quiz2.dta
	erase mainfile.dta
	erase survey-data.dta
	erase survey.dta
	erase survey2.dta
	erase Multi_Money-data2.dta