*********************************************************************
*	This program cleans and creates variables using the Multi_Money-data.dta file
*********************************************************************

clear all
capture log close
cd C:\temp\DATA\DataCleaning

use Multi_Money-data.dta
save Work_Data.dta, replace
macro define data "Work_Data.dta, clear"

drop strategies introvert emotional spontaneous timeLeisure timeSleep timeStudy timeWork  major_set  comments_set risk DN DO
drop Profit TotalProfit  totalTicketB totalTicketA  totalTicket  



**===========================================================================
**  Incentivized Quiz 
**===========================================================================
egen response_t=rowtotal(ResponseTime*)
gen wrong_ans=10-RightAnswer
	replace wrong_ans=wrong_ans/10
	label variable wrong_ans "Fraction of wrong answers in incentivized quiz (out of 10)"
	label variable response_t "Tot. time spent in answering incentivized quiz questions"
	drop ResponseTime*   RightAnswer

	
*** Session Variables ***
label variable ymd "Unique session ID (Year Month Day)"

rename Session Subject Group Treatment, lower
	label variable treatment "Treatment"
	label variable session  "Session" 
	label variable subject "Subject in a session"

rename timeChoice decision_time
	label variable decision_time  "Decision time"
	
rename Period period_session
	label variable period_session  "Period in a Session"

rename cycle game
	label variable game  "Supergame" 
	
rename periodCycle period
	label variable period "Period in a Supergame"

rename beginTicket balance
	label variable balance 	"Subject Tot. # of tokens (any) at period START"

rename beginTicketA 	balanceA
	label variable balanceA   "d-tokens (yellow) held at period START"

rename beginTicketB 	balanceB
	label variable balanceB "Fiat tokens (white) held at period START"

rename partner_tickets 	balance_o
	label variable balance_o  "Opponent's Tot. # of tokens (any) at period START"

rename partner_ticketsA 	balanceA_o
	label variable balanceA_o 	"d-tokens (yellow) of opponent at period START" 

rename partner_ticketsB 	balanceB_o
	label variable balanceB_o 	"Fiat tokens (white) of opponent at period START" 

rename tickets 	end_balance
	label variable end_balance "Subject Tot. # of tokens (any) at period END"

rename ticketsA 	end_balanceA
	label variable end_balanceA 	"d-tokens (Yellow) held at period END"

rename ticketsB 	end_balanceB
	label variable end_balanceB 	"Fiat tokens (White) held at period END"

rename dividend size_dividend
	label variable size_d 	"Dividend d (paid by yellow tickets) in a period"
	
rename roundPayoff profit_partial
	label variable profit_partial	 "Points from stage game (excludes dividend)"
	
rename totalPayoff profit
	label variable profit "Points earned in a period  (includes dividend)"

rename ticketPayoff div
	label variable div   "Dividends earned in a period"

label define outcomel 0 "D"   1 "C" 
	label values outcome outcomel
	label variable outcome "Outcome in a pair"
	
label define divl    1 "Penalty"      2 "Fiat"       3  "Reward"      4 "Reward2"      5 "Fiat2"   6 "Mix"   7 "Switch"
	label values treatment divl
	

*** PAYMENTS based on randomly selected block at end of session (rounded to next 25 cents interval)***
bysort treatment session game subject (period): egen dollar=sum(profit)
	replace dollar=dollar*0.15
	
gen quiz=round(payoffCQ1,0.25)		
	label variable quiz "$ earnings in Quiz" 
	
gen  paid=0.25*ceil(dollar/0.25) if treatment==4 & session==1 & game==1 
	replace paid=0.25*ceil(dollar/0.25) if treatment==4 & session==2 & game==2
	replace paid=0.25*ceil(dollar/0.25) if treatment==4 & session==3 & game==3
	
	replace paid=0.25*ceil(dollar/0.25) if treatment==1 & session==1 & game==2 
	replace paid=0.25*ceil(dollar/0.25) if treatment==1 & session==2 & game==4
	replace paid=0.25*ceil(dollar/0.25) if treatment==1 & session==3 & game==2
	
	replace paid=0.25*ceil(dollar/0.25) if treatment==2 & session==1 & game==1
	replace paid=0.25*ceil(dollar/0.25) if treatment==2 & session==2 & game==3
	replace paid=0.25*ceil(dollar/0.25) if treatment==2 & session==3 & game==5
	
	replace paid=0.25*ceil(dollar/0.25) if treatment==3 & session==1 & game==3
	replace paid=0.25*ceil(dollar/0.25) if treatment==3 & session==2 & game==1
	replace paid=0.25*ceil(dollar/0.25) if treatment==3 & session==3 & game==5

	replace paid=0.25*ceil(dollar/0.25) if treatment==6 & session==1 & game==2
	replace paid=0.25*ceil(dollar/0.25) if treatment==6 & session==2 & game==1
	replace paid=0.25*ceil(dollar/0.25) if treatment==6 & session==3 & game==3

	replace paid=0.25*ceil(dollar/0.25) if treatment==5 & session==1 & game==1
	replace paid=0.25*ceil(dollar/0.25) if treatment==5  & session==2 & game==5
	replace paid=0.25*ceil(dollar/0.25) if treatment==5  & session==3 & game==3

	replace paid=0.25*ceil(dollar/0.25) if treatment==7  & session==1 & game==4
	replace paid=0.25*ceil(dollar/0.25) if treatment==7  & session==2 & game==1
	replace paid=0.25*ceil(dollar/0.25) if treatment==7  & session==3 & game==5

	label variable paid "Salient $ earnings (from the game)" 
	drop dollar




	
***CONSTRUCT VARIABLES***
bysort treatment session game (period): gen duration=period[_N]
	label variable duration  "# rounds in game" 

bysort treat session subject  (game period): gen duration_lagged=duration[_n-1] if period==1
	replace duration_lagged=16 if game==1
	by treatment session subject game  (period), sort:  gen temp=duration_lagged[1]
	replace duration_lagged=temp
	drop temp
	label variable duration_lagged  "Rounds in previous supergame" 

bysort treatment session subject game: gen temp=duration if period==1
	bysort treatment session subject (game): gen tot_duration=sum(temp)-duration
	label variable tot_duration  "Tot. #  of rounds in PREVIOUS supergames" 
	drop temp

bysort treatment session subject (period_session): gen session_duration=period_session[_N] 
	label variable session_duration  "Tot. # of rounds in the Session" 

replace type=type-1
	label define typel 0 "Consumer"  1 "Producer"
	label values type typel
	label variable type "Role of subject"
	
by  treat session game period (subject), sort: gen subj_session=subject[_N]
	label variable subj_session  "Tot. # of subjects in a Session" 


**** TICKETS  ****
gen balance_cons=balance if type==0
gen balance_prod=balance if type==1
	label variable balance_cons "Consumer's TOT # of tokens at period Start"
	label variable balance_cons "Producer's TOT # of tokens at period Start"
	
gen TRANSF=0 
	replace TRANSF= transferreceive  if transferreceive==1
	replace TRANSF=-transfer if transfer==1
	drop transferreceive transfer
	rename TRANSF transfer
	label variable transfer "-1=spend ticket, 0 no trade, 1=earn ticket"	

gen transferA=end_balanceA - balanceA
gen transferB=end_balanceB - balanceB
	label variable transferA "-1=spend ticket A, 0 no trade w/ A, 1= earn ticket A"	
	label variable transferB "-1=spend ticket B, 0 no trade w/B, 1=earn ticket B"	
	
gen possibleA=(type==0 & balanceA>0 | type==1 & balanceA_o>0)
gen possibleB=(type==0 & balanceB>0 | type==1 & balanceB_o>0)
gen possible=(possibleA==1 | possibleB==1)
	label variable possibleA "Trade possible w/ d-ticket"
	label variable possibleB "Trade possible w/ Fiat-ticket"
	label variable possible "Trade is possible w/ SOME ticket"
	label define tradel 0 "Impossible"   1 "Possible"
	label values possible tradel
	label values possibleA tradel
	label values possibleB tradel
	


*** SUBJECTS, SESSIONS & ECONOMIES ***
egen ID=group(treatment session subject)
	label variable ID 	"Subject unique ID in experiment"

egen groupID=group(treatment session game group)	
	label variable groupID 	"Economy unique ID in experiment"

egen sessionID=group(treatment session)
	label variable sessionID "Session unique ID in experiment"
	

***  CHOICES ***
replace choice=. if choice==0
replace choice=choice-1 if choice>0
	label define choicel 	0 "D"   1 "C"   2 "C for d-token (Yellow)"  	3 "C for fiat (White)"   5 "Keep tokens"  6 "Spend d-token (Yellow)"   7 "Spend fiat (White)" 
	label values choice choicel
	label variable choice "Choice"

replace otherChoice=. if otherChoice==0
replace otherChoice=otherChoice-1 if otherChoice>0
	rename otherChoice choice_o
	label values choice_o choicel
	label variable choice_o "Opponent's choice"

gen intention=1 if type==1
	replace intention=0 if choice==0
	label values intention outcomel
	label variable intention "Producer w/ Cooperative Intention"

gen spend=0  if type==0 & possible==1
	replace spend=1 if (choice==6 | choice==7)
	label variable spend "Offers token (has some)"
	label define spendl 0 "Keep tokens"  1 "Offers token"   
	label values spend spendl

gen spendA=0  if type==0 & possibleA==1
gen spendB=0  if type==0 & possibleB==1
	replace spendA=1 if choice==6
	replace spendB=1 if choice==7
	label variable spendA "Offer d-token A"
	label variable spendB "Offer plain token B"
	label define spendlA 1 "Offer d-token"       0 "Keep d-token"
	label define spendlB 1 "Offer plain-token"   0 "Keep fiat token"
	label values spendA spendlA
	label values spendB spendlB

gen sell=0  if type==1 & possible==1
	replace sell=1 if (choice==2 | choice==3)
	label variable sell "C for some token (trade is possible)"
	label define sellL 	1 "C for a token "   0  "D or uncond. C"
	label values sell sellL
	
gen sellA=0  if type==1 & possibleA==1
gen sellB=0  if type==1 & possibleB==1
	replace sellA=1 if choice==2 
	replace sellB=1 if choice==3
	label variable sellA "C for d-token"
	label variable sellB "C for plain token"
	label values sellA sellL
	label values sellB sellL
	
gen trade=0
	replace trade=1 if  (type==1 & choice== 2 & choice_o== 6)  | (type==0 & choice== 6  & choice_o== 2) | (type==1 & choice== 3 & choice_o== 7)| (type==0 & choice== 7  & choice_o== 3)
	label variable trade "0=No Trade, 1=Monetary Trade"
	label define giftl 		0  "No Trade " 	1 "Trade" 
	label values trade giftl

	save data_used.dta, replace
	erase Work_Data.dta